/*
 * Copyright (c) 2006-2014 DMDirc Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.addons.ui_swing.components.text;

import com.dmdirc.util.URLBuilder;

import java.net.URL;

import javax.swing.text.Element;
import javax.swing.text.html.HTML;
import javax.swing.text.html.ImageView;

/**
 * DMDirc image view, extends default image view but uses DMDirc URLBuilder.
 */
public class DMDircImageView extends ImageView {

    /** The URL builder to use to construct image URLs. */
    private final URLBuilder urlBuilder;

    /**
     * Creates a new DMDirc image view.
     *
     * @param elem       element to view
     * @param urlBuilder The URL builder to use to construct image URLs.
     */
    public DMDircImageView(final URLBuilder urlBuilder, final Element elem) {
        super(elem);

        this.urlBuilder = urlBuilder;
    }

    /**
     * {@inheritDoc}
     *
     * @return URL to resource
     */
    @Override
    public URL getImageURL() {
        final String src = (String) getElement().getAttributes().
                getAttribute(HTML.Attribute.SRC);

        return src == null ? null : urlBuilder.getUrl(src);
    }

}
