/*
 * Copyright (c) 2006-2014 DMDirc Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.addons.ui_swing.dialogs.profiles;

import com.dmdirc.actions.wrappers.Profile;
import com.dmdirc.util.validators.FileNameValidator;
import com.dmdirc.util.validators.ValidationResponse;
import com.dmdirc.util.validators.Validator;
import com.dmdirc.util.validators.ValidatorChain;

import java.util.List;

/**
 * Validator to ensure a profile name is both unique and a valid name to be saved to disk.
 */
public class ProfileNameValidator implements Validator<String> {

    private final ValidatorChain<String> validator;

    /**
     * Creates a new profile name validator.
     *
     * @param profiles List of profiles to check uniqueness
     */
    public ProfileNameValidator(final List<Profile> profiles) {
        validator = ValidatorChain.<String>builder()
                .addValidator(new UniqueProfileNameValidator(profiles))
                .addValidator(new FileNameValidator())
                .build();
    }

    @Override
    public ValidationResponse validate(final String object) {
        return validator.validate(object == null ? "" : object.trim());
    }

}
